@@ -32,7 +32,7 @@
 #include <ctype.h>
 #include <gnome.h>
 
-#include "xst.h"
+#include "gst.h"
 #include "users-table.h"
 #include "table.h"
 #include "callbacks.h"
@@ -43,27 +43,29 @@
 
 #define MAX_TOKENS 8
 
-extern XstTool *tool;
-
-GtkWidget *user_settings_all = NULL;
-GtkWidget *user_settings_members = NULL;
+extern GstTool *tool;
+extern GList *groups_list;
+xmlNodePtr user_profile;
 
 static void
 create_groups_lists (xmlNodePtr node, GList **user_settings_all_list, GList **user_settings_members_list)
 {
 	*user_settings_members_list = user_get_groups (node);
-	*user_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("name", node), *user_settings_members_list);
+	*user_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("name", NODE_GROUP), *user_settings_members_list);
 }
 
 static void
 create_groups_gtk_trees (void)
 {
+	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	GtkWidget *add_button, *remove_button;
 	GtkTreeSelection *selection;
+	GtkSizeGroup *sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 	
-	/* We create the widgets, connect signals and attach data if they haven't been created already */
-	if (user_settings_all == NULL) {
-		user_settings_all = create_gtk_tree_list (xst_dialog_get_widget (tool->main_dialog, "user_settings_all"));
+	/* connect signals and attach data if they haven't been created already */
+	if (g_object_get_data (G_OBJECT (user_settings_all), "button") == NULL) {
+		create_gtk_tree_list (user_settings_all);
 		g_object_set_data (G_OBJECT (user_settings_all), "button", "user_settings_add");
 		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_settings_all));
 		g_signal_connect (G_OBJECT (selection),
@@ -71,7 +73,7 @@ create_groups_gtk_trees (void)
 		                  G_CALLBACK (on_list_select_row),
 		                  NULL);
 
-		user_settings_members = create_gtk_tree_list (xst_dialog_get_widget (tool->main_dialog, "user_settings_members"));
+		create_gtk_tree_list (user_settings_members);
 		g_object_set_data (G_OBJECT (user_settings_members), "button", "user_settings_remove");
 		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_settings_members));
 		g_signal_connect (G_OBJECT (selection),
@@ -80,13 +82,17 @@ create_groups_gtk_trees (void)
 		                  NULL);
 
 		/* We also need to attach some data to the 'add' and 'remove' buttons */
-		add_button = xst_dialog_get_widget (tool->main_dialog, "user_settings_add");
+		add_button = gst_dialog_get_widget (tool->main_dialog, "user_settings_add");
 		g_object_set_data (G_OBJECT (add_button), "in", user_settings_all);
 		g_object_set_data (G_OBJECT (add_button), "out", user_settings_members);
 		
-		remove_button = xst_dialog_get_widget (tool->main_dialog, "user_settings_remove");
+		remove_button = gst_dialog_get_widget (tool->main_dialog, "user_settings_remove");
 		g_object_set_data (G_OBJECT (remove_button), "in", user_settings_members);
 		g_object_set_data (G_OBJECT (remove_button), "out", user_settings_all);
+
+		/* Add the scrolled windows that contain the trees in the same GtkSizeGroup */
+		gtk_size_group_add_widget (sizegroup, gst_dialog_get_widget (tool->main_dialog, "group_settings_all_container"));
+		gtk_size_group_add_widget (sizegroup, gst_dialog_get_widget (tool->main_dialog, "group_settings_members_container"));
 	}
 }
 
@@ -101,7 +107,7 @@ check_user_delete (xmlNodePtr node)
 	g_return_val_if_fail (node != NULL, FALSE);
 
 	parent = GTK_WINDOW (tool->main_dialog);
-	login = xst_xml_get_child_content (node, "login");
+	login = gst_xml_get_child_content (node, "login");
 
 	if (!login)
 	{
@@ -131,148 +137,79 @@ check_user_delete (xmlNodePtr node)
 		return TRUE;
 }
 
-void
+gboolean
 delete_user (xmlNodePtr node)
 {
 	if (check_user_delete (node))
 	{
 		del_user_groups (node);
-		xst_xml_element_destroy (node);
-	} 
-}
-
-static void
-shells_combo_setup ()
-{
-	xmlNodePtr root, node;
-	GtkWidget *combo;
-	GList *shells = NULL;
-	gchar *shell;
-
-	root = xst_xml_doc_get_root (tool->config);
-	root = xst_xml_element_find_first (root, "shelldb");
-	combo = xst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
-
-	if (!root)
-		return;
-	
-	for (node = xst_xml_element_find_first (root, "shell"); node != NULL; node = xst_xml_element_find_next (node, "shell"))
-	{
-		shell = xst_xml_element_get_content (node);
-		shells = g_list_append (shells, shell);
+		gst_xml_element_destroy (node);
+		return TRUE;
 	}
 
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), shells);
-	g_list_free (shells);
-}
-
-static void
-groups_combo_setup (gchar *entry)
-{
-	GList *groups;
-	GtkWidget *combo = xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo");
-	gboolean found = FALSE;
-	ug_data *ud;
-
-	ud = g_object_get_data (G_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog")), "data");
-
-	groups = get_list_from_node ("name", ud->node);
-	
-	g_return_if_fail (groups != NULL);
-	
-	if (entry) {
-		GList *list = groups;
-		while (list && !found) {
-			if (strcmp (list->data, entry) == 0) {
-				found = TRUE;
-				break;
-			}
-			list = list->next;
-		}
-		
-		if (!found) {
-			groups = g_list_prepend (groups, entry);
-		}
-	}
-	
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), groups);
-	gtk_combo_set_value_in_list (GTK_COMBO (combo), TRUE, FALSE);
-	
-	g_list_free (groups);
+	return FALSE;
 }
 
 void
-user_set_profile (const gchar *profile)
+user_set_profile (xmlNodePtr profile)
 {
-	GtkWidget *widget;
-	xmlNodePtr node, root;
+	gint counter = 0;
+	GList *element;
+	gchar *value;
 	gchar *buf;
+	ug_data *ud;
+	GtkWidget *widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	
-	g_return_if_fail (profile != NULL);
+	ud = g_object_get_data (G_OBJECT (widget), "data");
 	
-	root = xst_xml_doc_get_root (tool->config);
-	root = xst_xml_element_find_first (root, "profiledb");
-	
-	for (node = xst_xml_element_find_first (root, "profile"); node != NULL; xst_xml_element_find_next (node, "profile")) {
-		if (strcmp (profile, xst_xml_get_child_content (node, "name")) == 0)
-			break;
+	gtk_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_home")),
+			    gst_xml_get_child_content (profile, "home_prefix"));
+	gtk_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")),
+			    gst_xml_get_child_content (profile, "shell"));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_max")),
+				   g_strtod (gst_xml_get_child_content (profile, "pwd_maxdays"), NULL));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_min")),
+				   g_strtod (gst_xml_get_child_content (profile, "pwd_mindays"), NULL));
+	gtk_spin_button_set_value ( GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_days")),
+				   g_strtod (gst_xml_get_child_content (profile, "pwd_warndays"), NULL));
+
+	value = gst_xml_get_child_content (profile, "group");
+	element = g_list_first (groups_list);
+
+	while ((element != NULL) && (strcmp (element->data, value) != 0))
+	{
+		element = element->next;
+		counter++;
 	}
-	
-	xst_ui_entry_set_text (xst_dialog_get_widget (tool->main_dialog, "user_settings_home"), xst_xml_get_child_content (node, "home_prefix"));
-	xst_ui_entry_set_text (xst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry"), xst_xml_get_child_content (node, "shell"));
-	
-	buf = xst_xml_get_child_content (node, "group");
-	groups_combo_setup (buf);
-	xst_ui_entry_set_text (xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo_entry"), buf);
+	gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
 
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_max")), g_strtod (xst_xml_get_child_content (node, "pwd_maxdays"), NULL));
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_min")), g_strtod (xst_xml_get_child_content (node, "pwd_mindays"), NULL));
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_days")), g_strtod (xst_xml_get_child_content (node, "pwd_warndays"), NULL));
-}
-
-static void
-profiles_option_menu_setup (void)
-{
-	GtkWidget *menu_item;
-	GtkWidget *menu = xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu");
-	GList *profiles = get_profile_list ();
-	GList *list = profiles;
-	gint index, i=0;
-	
-	while (list) {
-		if (strcmp (list->data, "Default") == 0)
-			index = i;
-		menu_item = xst_ui_option_menu_add_string (GTK_OPTION_MENU (menu), list->data);
-		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK (on_user_settings_profile_changed), list->data);
-		list = list->next;
-		i++;
+	/* Gets a new uid */
+	buf = (gchar *) find_new_id (ud->node, profile);
+	if (buf) {
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_settings_uid")), 
+		                           g_strtod (buf, NULL));
+		g_free (buf);
 	}
-	
-	/* we set the option menu to the 'Default' option */
-	gtk_option_menu_set_history (GTK_OPTION_MENU (menu), index);
-	user_set_profile ("Default");
 
-	g_list_free (profiles);
+	user_profile = profile;
 }
 
 void
 user_new_prepare (ug_data *ud)
 {
-	GtkWidget *widget, *button;
+	GtkWidget *button;
 	gchar *buf;
 	GList *user_settings_all_list = NULL;
 	GList *user_settings_members_list = NULL;
+	GtkWidget *widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	gtk_window_set_title (GTK_WINDOW (widget), _("User Account Editor"));
-
-	/* Attach the data to the dialog */
 	g_object_set_data (G_OBJECT (widget), "data", ud);
-	
-	/* Profiles are disabled at the moment, showing advanced settings instead */
-	gtk_widget_show (xst_dialog_get_widget (tool->main_dialog, "user_settings_advanced"));
-	gtk_widget_hide (xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_box"));
 
+	gtk_widget_show (gst_dialog_get_widget (tool->main_dialog, "user_settings_profiles"));
+	
 	/* Creates and fills GtkTrees */
 	create_groups_gtk_trees ();
 	create_groups_lists (ud->node, &user_settings_all_list, &user_settings_members_list);
@@ -282,20 +219,14 @@ user_new_prepare (ug_data *ud)
 	g_object_set_data (G_OBJECT (user_settings_all), "list", user_settings_all_list);
 	g_object_set_data (G_OBJECT (user_settings_members), "list", user_settings_members_list);
 	
-	/* Fills profiles option menu */
-	profiles_option_menu_setup ();
+	/* Fill menus */
+	option_menu_add_profiles (gst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu"));
+	option_menu_add_groups (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"), TRUE);
+	combo_add_shells (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"));
 	
-	/* Gets a new uid */
-	buf = (gchar *) find_new_id (ud->node);
-	if (buf) {
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_settings_uid")), 
-		                           g_strtod (buf, NULL));
-		g_free (buf);
-	}
-	
-	/* If we have libcrack, password quality check is enabled */
-	button = xst_dialog_get_widget (tool->main_dialog, "user_passwd_quality");
 #ifdef HAVE_LIBCRACK
+	/* If we have libcrack, password quality check is enabled */
+	button = gst_dialog_get_widget (tool->main_dialog, "user_passwd_quality");
 	gtk_widget_show (button);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 #endif
@@ -306,6 +237,8 @@ user_new_prepare (ug_data *ud)
 void
 user_settings_dialog_close (void)
 {
+	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	GtkWidget *widget;
 	GtkTreeModel *model;
 	ug_data *ud;
@@ -325,7 +258,7 @@ user_settings_dialog_close (void)
 		
 	/* Clear text boxes */
 	for (i = 0; text_boxes[i]; i++) {
-		widget = xst_dialog_get_widget (tool->main_dialog, text_boxes[i]);
+		widget = gst_dialog_get_widget (tool->main_dialog, text_boxes[i]);
 		gtk_entry_set_text (GTK_ENTRY (widget), "");
 	}
 
@@ -337,17 +270,17 @@ user_settings_dialog_close (void)
 	gtk_tree_store_clear (GTK_TREE_STORE (model));
 	
 	/* Set unsensitive the add and remove buttons */
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_add");
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_add");
 	gtk_widget_set_sensitive (widget, FALSE);
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_remove");
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_remove");
 	gtk_widget_set_sensitive (widget, FALSE);
 	
 	/* Set the manual password */
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_passwd_manual");
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 	
 	/* Set the first notebook page as default for the next time the dialog is opened */
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 0);
 	
 	/* Clear the GLists attached to the GtkTreeViews */
@@ -360,11 +293,14 @@ user_settings_dialog_close (void)
 	g_object_steal_data (G_OBJECT (user_settings_members), "list");
 
 	/* Clear user data attached to the widget */
-	widget = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	ud = g_object_get_data (G_OBJECT (widget), "data");
 	g_free (ud);
 	g_object_steal_data (G_OBJECT (widget), "data");
 	gtk_widget_hide (widget);
+
+	/* Clear groups option menu */
+	gtk_option_menu_remove_menu (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")));
 }
 
 static gboolean
@@ -377,7 +313,7 @@ is_user_root (xmlNodePtr node)
 		return FALSE;
 	} else {
 		/* node isn't set to userdb node, this means that the user is being modified */
-		login = xst_xml_get_child_content (node, "login");
+		login = gst_xml_get_child_content (node, "login");
 	
 		if (strcmp (login, "root") == 0)
 			return TRUE;
@@ -584,7 +520,7 @@ group_check (xmlNodePtr node, const gchar *groupname)
 	
 	gid = group_xml_get_gid (groupdb, (gchar *) groupname);
 	if (!gid) {
-		gid = find_new_id (groupdb);
+		gid = find_new_id (groupdb, user_profile);
 		group = group_add_blank_xml (groupdb);
 		group_update_xml (group, (gchar *) groupname, gid, NULL);
 	}
@@ -595,6 +531,7 @@ group_check (xmlNodePtr node, const gchar *groupname)
 gboolean
 user_update (ug_data *ud)
 {
+	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	UserAccountData *data;
 	gboolean change_password = FALSE;
 	GList *list;
@@ -602,16 +539,16 @@ user_update (ug_data *ud)
 	data = g_new (UserAccountData, 1);
 	
 	/* check user login */
-	data->login = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_name")));
+	data->login = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_name")));
 	if (!is_login_valid (ud->node, data->login)) {
 		return FALSE;
 	}
 	
 	/* check user comments */
-	data->name = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_comment")));
-	data->location = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_office")));
-	data->work_phone = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_wphone")));
-	data->home_phone = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_hphone")));
+	data->name = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_comment")));
+	data->location = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_office")));
+	data->work_phone = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_wphone")));
+	data->home_phone = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_hphone")));
 	if (!is_comment_valid (data->name, data->location, data->work_phone, data->home_phone)) {
 		return FALSE;
 	}
@@ -619,37 +556,37 @@ user_update (ug_data *ud)
 	/* check user home */
 	if (ud->is_new) {
 		/* The user is new, home must be parsed to replace the '$user' tag */
-		data->home = parse_user_home ((gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_home"))), data->login);
+		data->home = parse_user_home ((gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_home"))), data->login);
 	} else {
-		data->home = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_home")));
+		data->home = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_home")));
 	}
 	if (!is_home_valid (ud->node, data->home)) {
 		return FALSE;
 	}
 	
 	/* check user uid */
-	data->uid = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_settings_uid"))));
+	data->uid = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_settings_uid"))));
 	if (!is_user_uid_valid (ud->node, data->uid)) {
 		return FALSE;
 	}
 	
 	/* check user shell */
-	data->shell = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")));
+	data->shell = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")));
 	if (!is_shell_valid (data->shell)) {
 		return FALSE;
 	}
 	
 	/* check user password */
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_manual")))) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual")))) {
 		/* Manual password enabled */
 		if (!ud->is_new) {
 			/* If it is a modified user, we have to check that the entries are unchanged */
 			gboolean d1, d2;
-			d1 = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")), "changed"));
-			d2 = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")), "changed"));
+			d1 = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")), "changed"));
+			d2 = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")), "changed"));
 			if (d1 || d2) {
-				data->password1 = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")));
-				data->password2 = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")));
+				data->password1 = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")));
+				data->password2 = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")));
 				if (!is_password_valid (data->password1, data->password2)) {
 					return FALSE;
 				}
@@ -657,19 +594,19 @@ user_update (ug_data *ud)
 			}
 		} else {
 			/* If it is a new user, we have to check it anyway */
-			data->password1 = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")));
-			data->password2 = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")));
+			data->password1 = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1")));
+			data->password2 = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2")));
 			if (!is_password_valid (data->password1, data->password2)) {
 				return FALSE;
 			}
 		}
 	} else {
 		/* Automatic password generation enabled */
-		data->password1 = (gchar *) gtk_label_get_text (GTK_LABEL (xst_dialog_get_widget (tool->main_dialog, "user_passwd_random_label")));
+		data->password1 = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_passwd_random_entry")));
 	}
 
 	/* get user main group GID*/
-	data->group = (gchar *) gtk_entry_get_text (GTK_ENTRY (xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo_entry")));
+	data->group = g_list_nth_data (groups_list, gtk_option_menu_get_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"))));
 	if (strcmp (data->group, "$user") == 0)
 		data->group = data->login;
 	
@@ -681,9 +618,9 @@ user_update (ug_data *ud)
 	g_list_free (data->extra_groups);
 	data->extra_groups = g_list_copy (g_object_get_data (G_OBJECT (user_settings_members), "list"));
 
-	data->pwd_maxdays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_max"))));
-	data->pwd_mindays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_min"))));
-	data->pwd_warndays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "user_passwd_days"))));
+	data->pwd_maxdays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_max"))));
+	data->pwd_mindays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_min"))));
+	data->pwd_warndays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_days"))));
 	
 	if (ud->is_new) {
 		/* Add new user, update table */
@@ -706,8 +643,8 @@ static void
 user_settings_dialog_prepare_password (void){
 	GtkWidget *pwd1, *pwd2;
 	
-	pwd1 = xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1");
-	pwd2 = xst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2");
+	pwd1 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry1");
+	pwd2 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_entry2");
 	
 	gtk_entry_set_text (GTK_ENTRY (pwd1), "********");
 	gtk_entry_set_text (GTK_ENTRY (pwd2), "********");
@@ -734,8 +671,8 @@ user_settings_dialog_prepare_comments (gchar *comments)
 	buf = g_strsplit (comments, ",", 4);
 	
 	for (i = 0; buf[i] != NULL; i++) {
-		w0 = xst_dialog_get_widget (tool->main_dialog, widgets[i]);
-		xst_ui_entry_set_text (w0, buf[i]);
+		w0 = gst_dialog_get_widget (tool->main_dialog, widgets[i]);
+		gst_ui_entry_set_text (w0, buf[i]);
 		g_free (buf[i]);
 	}
 }
@@ -743,54 +680,67 @@ user_settings_dialog_prepare_comments (gchar *comments)
 static void
 user_settings_dialog_prepare (ug_data *ud)
 {
+	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
+	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
+	GtkWidget *option_menu = gst_dialog_get_widget (tool->main_dialog, "user_settings_group");
+	GtkWidget *combo = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
 	GtkWidget *w0;
 	gchar *txt, *name;
 	GList *user_settings_all_list = NULL;
 	GList *user_settings_members_list = NULL;
+	gint counter = 0;
+	GList *element;
 	
 	g_return_if_fail (ud != NULL);
 
-	/* Hides profiles combo, shows advanced settings */
-	gtk_widget_show (xst_dialog_get_widget (tool->main_dialog, "user_settings_advanced"));
-	gtk_widget_hide (xst_dialog_get_widget (tool->main_dialog, "user_settings_profile_box"));
+	gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "user_settings_profiles"));
 	
 	/* Attach the data to the dialog */
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	g_object_set_data (G_OBJECT (w0), "data", ud);
 
 	/* Set user login */
-	name = xst_xml_get_child_content (ud->node, "login");
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_name");
-	xst_ui_entry_set_text (w0, name);
+	name = gst_xml_get_child_content (ud->node, "login");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_name");
+	gst_ui_entry_set_text (w0, name);
 
 	/* Set comments */
-	user_settings_dialog_prepare_comments (xst_xml_get_child_content (ud->node, "comment"));
+	user_settings_dialog_prepare_comments (gst_xml_get_child_content (ud->node, "comment"));
 	
 	/* Set UID */
-	txt = xst_xml_get_child_content (ud->node, "uid");
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_uid");
+	txt = gst_xml_get_child_content (ud->node, "uid");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_uid");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 	g_free (txt);
 	
 	/* Set home directory */
-	txt = xst_xml_get_child_content (ud->node, "home");
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_home");
-	xst_ui_entry_set_text (w0, txt);
+	txt = gst_xml_get_child_content (ud->node, "home");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_home");
+	gst_ui_entry_set_text (w0, txt);
 	g_free (txt);
 	
 	/* Set shells combo */
-	shells_combo_setup ();
-	txt = xst_xml_get_child_content (ud->node, "shell");
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry");
-	xst_ui_entry_set_text (w0, txt);
+	combo_add_shells (combo);
+	txt = gst_xml_get_child_content (ud->node, "shell");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry");
+	gst_ui_entry_set_text (w0, txt);
 	g_free (txt);
 	
-	/* set main group combo */
-	groups_combo_setup (NULL);
-	txt = get_group_name (xst_xml_get_child_content (ud->node, "gid"));
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_group_combo_entry");
-	xst_ui_entry_set_text (w0, txt);
-	g_free (txt);
+	/* set main group option menu */
+	option_menu_add_groups (option_menu, FALSE);
+	txt = get_group_name (gst_xml_get_child_content (ud->node, "gid"));
+
+	if (txt != NULL) {
+		element = g_list_first (groups_list);
+
+		while ((element != NULL) && (strcmp (element->data, txt) != 0))
+		{
+			element = element->next;
+			counter++;
+		}
+		gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
+		g_free (txt);
+	}
 	
 	/* Fill groups lists */
 	create_groups_gtk_trees ();
@@ -806,30 +756,28 @@ user_settings_dialog_prepare (ug_data *ud)
 	user_settings_dialog_prepare_password ();
 	
 	/* Set maxdays */
-	txt = xst_xml_get_child_content (ud->node, "passwd_max_life");
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_passwd_max");
+	txt = gst_xml_get_child_content (ud->node, "passwd_max_life");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_max");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 	g_free (txt);
 	
 	/* Set mindays */
-	txt = xst_xml_get_child_content (ud->node, "passwd_min_life");
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_passwd_min");
+	txt = gst_xml_get_child_content (ud->node, "passwd_min_life");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_min");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 	g_free (txt);
 	
 	/* Set warndays */
-	txt = xst_xml_get_child_content (ud->node, "passwd_exp_warn");
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_passwd_days");
+	txt = gst_xml_get_child_content (ud->node, "passwd_exp_warn");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_days");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 	g_free (txt);
 	
 	/* Set window title */
-	w0 = xst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	gtk_window_set_title (GTK_WINDOW (w0), g_strdup_printf (_("Settings for user %s"), name));
 	g_free (name);
 	
-	
-
 	gtk_widget_show (w0);
 }
 
@@ -840,7 +788,7 @@ user_settings_prepare (ug_data *ud)
 	
 	g_return_if_fail (ud != NULL);
 
-	buf = xst_xml_get_child_content (ud->node, "name");
+	buf = gst_xml_get_child_content (ud->node, "name");
 
 	if (buf)
 	{
@@ -850,7 +798,7 @@ user_settings_prepare (ug_data *ud)
 		return;
 	}
 
-	buf = xst_xml_get_child_content (ud->node, "login");
+	buf = gst_xml_get_child_content (ud->node, "login");
 
 	if (buf)
 	{
